=============================
My Checker
=============================

.. image:: https://img.shields.io/pypi/v/my_checker.svg
  :target: https://pypi.python.org/pypi/my_checker
  :alt: PyPi

.. image:: https://travis-ci.org/mareuter/my_checker.svg?branch=master
  :target: https://travis-ci.org/mareuter/my_checker

.. image:: https://readthedocs.org/projects/my_checker/badge/?version=latest
  :target: http://my-checker.readthedocs.io/en/latest/?badge=latest
  :alt: Documentation Status

.. image:: https://img.shields.io/badge/license-MIT-blue.svg
   :target: http://opensource.org/licenses/MIT
   :alt: MIT License

Quick math checker


Features
--------

* Simple expression evaluation.

